@@ -1,20 +1,18 @@
-(*
- * bibtex2html - A BibTeX to HTML translator
- * Copyright (C) 1997-2000 Jean-Christophe Fillitre and Claude March
- * 
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2, as published by the Free Software Foundation.
- * 
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * See the GNU General Public License version 2 for more details
- * (enclosed in the file GPL).
- *)
-
-(*i $Id: bib2bib.ml,v 1.27 2008-12-11 16:05:55 marche Exp $ i*)
+(**************************************************************************)
+(*  bibtex2html - A BibTeX to HTML translator                             *)
+(*  Copyright (C) 1997-2010 Jean-Christophe Fillitre and Claude March   *)
+(*                                                                        *)
+(*  This software is free software; you can redistribute it and/or        *)
+(*  modify it under the terms of the GNU General Public                   *)
+(*  License version 2, as published by the Free Software Foundation.      *)
+(*                                                                        *)
+(*  This software is distributed in the hope that it will be useful,      *)
+(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
+(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                  *)
+(*                                                                        *)
+(*  See the GNU General Public License version 2 for more details         *)
+(*  (enclosed in the file GPL).                                           *)
+(**************************************************************************)
 
 open Printf
 open Bibtex
@@ -26,6 +24,8 @@ let input_file_names = ref ([] : string list)
 
 let bib_output_file_name = ref ""
 
+let php_output_file_name = ref ""
+
 let cite_output_file_name = ref ""
 
 let get_input_file_name f =
@@ -51,26 +51,49 @@ let expand_abbrevs = ref false
 
 let expand_xrefs = ref false
 
+let no_comment = ref false
+
 let sort_criteria = ref []
 
 let reverse_sort = ref false
 
+let remove_fields = ref []
+
+let rename_field = ref ""
+
+let rename_fields = ref []
+
 let args_spec =
   [
     ("-ob", Arg.String (fun f -> bib_output_file_name := f),
-     "bib output file name");
+     "<f> uses <f> as name for output bibliography file");
     ("-oc", Arg.String (fun f -> cite_output_file_name := f),
-     "citations output file name");
-    ("-c", Arg.String (add_condition),"filter condition");
+     "<f> uses <f> as name for output citations file");
+    ("--php-output", Arg.String (fun f -> php_output_file_name := f),
+     "<f> outputs resulting bibliography in PHP syntax in file <f>");
+    ("-c", Arg.String (add_condition),"<c> adds <c> as a filter condition");
     ("-w", Arg.Set Options.warn_error, "stop on warning");
     ("--warn-error", Arg.Set Options.warn_error, "stop on warning");
     ("-d", Arg.Set Options.debug, "debug flag");
     ("-q", Arg.Set Options.quiet, "quiet flag");
     ("--quiet", Arg.Set Options.quiet, "quiet flag");
-    ("-s", Arg.String (fun s -> sort_criteria := (String.lowercase s):: !sort_criteria),
-     "sort with respect to keys or a given field");
+    ("-s", Arg.String 
+       (fun s -> sort_criteria := (String.lowercase s):: !sort_criteria),
+     "<c> sort with respect to keys (if c=$keys) or a given field <c>");
     ("-r", Arg.Set reverse_sort,
      "reverse the sort order");
+    ("--no-comment", Arg.Unit (fun () -> no_comment := true), 
+     "do not add extra comments at beginning");
+    ("--remove", Arg.String 
+       (fun s -> remove_fields := (String.lowercase s):: !remove_fields),
+          "<f> removes the field <f>");
+    ("--rename", 
+     Arg.Tuple 
+       [ Arg.Set_string rename_field ;
+         Arg.String (fun s -> rename_fields := 
+                       (String.lowercase !rename_field,
+                        String.lowercase s):: !rename_fields)], 
+       "<f1> <f2> rename field <f1> into <f2>");
     ("--expand", Arg.Unit (fun () -> expand_abbrevs := true), 
      "expand the abbreviations");
     ("--expand-xrefs", Arg.Unit (fun () -> expand_xrefs := true), 
@@ -97,7 +120,7 @@ let output_cite_file keys =
 
 
 
-let output_bib_file biblio keys = 
+let output_bib_file remove rename biblio keys = 
   try 
     let ch = 
       if !bib_output_file_name = "" 
@@ -117,6 +140,7 @@ let output_bib_file biblio keys =
 	"" 
     in 
     let comments =
+      if !no_comment then empty_biblio else
       add_new_entry
 	(Comment ("Command line:" ^ cmd))
 	(add_new_entry 
@@ -126,13 +150,33 @@ let output_bib_file biblio keys =
 	   empty_biblio)
     in
     let biblio = merge_biblios comments biblio in
-    Biboutput.output_bib ~html:false ch biblio keys; 
+    Biboutput.output_bib ~remove ~rename ~html:false ch biblio keys;     
     if !bib_output_file_name <> "" then close_out ch
   with Sys_error msg ->  
     prerr_endline ("Cannot write output bib file (" ^ msg ^ ")"); 
     exit 1 
 
 
+let output_php_file remove rename biblio keys = 
+  if !php_output_file_name <> "" then
+    try
+      let ch = open_out !php_output_file_name in
+      output_string ch "<?php
+$parsed_bibfile = 
+Array
+(
+";
+    Biboutput.output_bib ~remove ~rename ~html:false ~php:true ch biblio keys;
+    output_string ch "
+ );
+?>
+";
+    close_out ch
+    with Biboutput.Bad_input_for_php msg ->
+      eprintf "error while producing PHP output: %s\n" msg;
+      exit 2
+      
+
 let rec make_compare_fun db criteria c1 c2 =
   match criteria with
     | [] -> 0	
@@ -249,7 +293,8 @@ let main () =
       b
   in
   output_cite_file matching_keys;
-  output_bib_file final_bib (Some needed_keys)
+  output_bib_file !remove_fields !rename_fields final_bib (Some needed_keys);
+  output_php_file !remove_fields !rename_fields final_bib (Some needed_keys)
 
 
 let _ = 
