@@ -311,7 +311,7 @@ def "\\." [Raw_arg (function "a" -> print_s "&#x227;"
 			   | "z" -> print_s "&#380;"
 			   | "Z" -> print_s "&#379;"
 			   | s   -> print_s s)];
-def "\\u" [Raw_arg(function "a" -> print_s "&#x101;"
+def "\\u" [Raw_arg(function "a" -> print_s "&#x103;"
 			   | "A" -> print_s "&#x102;"
 			   | "e" -> print_s "&#x115;"
 			   | "E" -> print_s "&#x114;"
@@ -320,8 +320,6 @@ def "\\u" [Raw_arg(function "a" -> print_s "&#x101;"
 			   | "I" -> print_s "&#x12D;"
 			   | "g" -> print_s "&#x11F;"
 			   | "G" -> print_s "&#x11E;"
-			   | "n" -> print_s "&#x148;"
-			   | "N" -> print_s "&#x147;"
 			   | "o" -> print_s "&#x14F;"
 			   | "O" -> print_s "&#x14E;"
 			   | "u" -> print_s "&#x16D;"
