@@ -143,7 +143,11 @@ let call_bibtex tmp =
       else 
 	"" 
     in
-    Sys.command (sprintf "%s %s %s" !command tmp redir)
+    let cmd = sprintf "%s %s %s" !command tmp redir in
+    if !Options.debug then begin 
+      eprintf "\nbibtex command: %s\n" cmd; flush stderr
+    end;
+    Sys.command cmd
   with
     | 0 -> 
 	if not !Options.quiet then begin eprintf "\n"; flush stderr end
@@ -460,6 +464,10 @@ i*)
 	add_note_field s; parse_rec rem
     | ("-note" | "--note") :: [] ->
 	usage()
+    | ("-note-html" | "--note-html") :: s :: rem ->
+	add_note_html_field s; parse_rec rem
+    | ("-note-html" | "--note-html") :: [] ->
+	usage()
     | ("-ln" | "-labelname" | "--labelname" | "--label-name") :: rem ->
 	use_label_name := true; parse_rec rem
     | ("-multiple" | "--multiple") :: rem ->
